/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* NetworkManager system settings service
 *
 * Mikhail Efremov <sem@altlinux.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2008 - 2011 Mikhail Efremov
 */

#include "common.h"
#include <netinet/ether.h>

char *
get_iface_name (const char *iface_path)
{
	return g_path_get_basename (iface_path);
}

char *
get_filename_with_profile(const char *file, const char *profile)
{
	return profile != NULL ? g_strdup_printf("%s#%s", file, profile) : g_strdup(file);
}

GByteArray *
get_ether_addr_array(const char *addr_str)
{
	struct ether_addr *tmp;
	GByteArray *array = NULL;

	g_return_val_if_fail(addr_str != NULL, NULL);

	tmp = ether_aton (addr_str);
	if (tmp) {
		array = g_byte_array_sized_new (ETH_ALEN);
		g_byte_array_append (array, (guint8 *) tmp->ether_addr_octet, ETH_ALEN);
	}

	return array;
}

GQuark
ifcfg_plugin_error_quark (void)
{
	static GQuark error_quark = 0;

	if (G_UNLIKELY (error_quark == 0))
		error_quark = g_quark_from_static_string ("ifcfg-plugin-error-quark");

	return error_quark;
}

